#include <string.h>
#include <ctype.h>
#include <signal.h>
#include <stdlib.h>
#include <unistd.h>

#include <radiusclient.h>

#define RESULT_OK 0
#define RESULT_WARNING 1
#define RESULT_UNKNOWN -1
#define RESULT_CRITICAL 2

#define CONFIG_FILE argv[1]
#define USERNAME argv[2]
#define PASSWORD argv[3]
#define TIMEOUT argv[4]
#define RETRIES argv[5]
#define AUTHSERVER argv[6]
#define AUTHPORT argv[7]
#define RESPONSE argv[8]


ENV *env = NULL;

void netsaintexit(char *msg, int code)
{
  puts(msg);
  exit(code);
}


int
main (int argc, char **argv)
{
  UINT4 service;
  char msg[4096];
  SEND_DATA       data={0};
  int             result;

  if (argc != 9)
    netsaintexit("Usage: "
		 "check_radius "
		 "<path_to_config_file> "
		 "<username> "
		 "<password> "
		 "<timeout_in_seconds> "
		 "<retries> "
		 "<auth_server> "
		 "<auth_port> "
		 "<response>",RESULT_UNKNOWN);

  if (rc_read_config(CONFIG_FILE) ||
      rc_read_dictionary(rc_conf_str("dictionary")))
    netsaintexit("Config file error",RESULT_UNKNOWN);

  service = PW_LOGIN;

  if (!(rc_avpair_add(&data.send_pairs, PW_SERVICE_TYPE, &service, 0) &&
	rc_avpair_add(&data.send_pairs, PW_USER_NAME, USERNAME, 0) &&
	rc_avpair_add(&data.send_pairs, PW_USER_PASSWORD, PASSWORD, 0)))
    netsaintexit("Out of Memory?",RESULT_UNKNOWN);

  rc_buildreq(&data, PW_ACCESS_REQUEST, AUTHSERVER, atoi(AUTHPORT), atoi(TIMEOUT), atoi(RETRIES));
  
  result = rc_send_server(&data, msg);
  rc_avpair_free(data.send_pairs);
  if (data.receive_pairs) rc_avpair_free(data.receive_pairs);

  if (result == TIMEOUT_RC) netsaintexit("Timeout",RESULT_CRITICAL);
  if (result == ERROR_RC) netsaintexit("Auth Error",RESULT_CRITICAL);
  if (result == BADRESP_RC) netsaintexit("Auth Failed",RESULT_WARNING);
  if (!strstr(msg,RESPONSE)) netsaintexit(msg,RESULT_WARNING);
  if (result == OK_RC) netsaintexit("Success",RESULT_OK);
  return(0);
}

